from setuptools import setup, find_packages

setup(
    name='cigaro',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[],
    author='XORbit',
    description='A Python library for wrapping binary command tools',
    url='https://github.com/Malwarize/cigaro',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
    ],
)
